# supernova

Object-oriented python library for analyzing supernova data, focusing on generic data flow, conversion, and convenient plotting. 
The scripts are meant to be imported and used inside external plotting and analysis codes/notebooks. (See SN2020lao directory for an example)

Will also be a way to quickly import the SN data from my papers. However, please do not take it without
referring to/citing the paper, (or publish it before mine is accepted without contacting me), thanks!
